from pyramid.threadlocal import get_current_request
from translationstring import TranslationStringFactory
from pyramid.i18n import get_localizer

class PyramidTranslator(object):

    def __init__(self, domain='deform'):
        self.domain = domain

    def translate(self, term):

        if not hasattr(term, 'interpolate'): # not a translation string
            term = TranslationStringFactory(self.domain)(term)
        return get_localizer(get_current_request()).translate(term)

    def pluralize(self, term):
        if not hasattr(term, 'interpolate'): # not a translation string
            term = TranslationStringFactory(self.domain)(term)
        return get_localizer(get_current_request()).pluralize(term)


    def gettext(self, message):
        return self.translate(message)

    def ngettext(self, singular, plural, n):
        return self.pluralize(singular, plural, n)




from jinja2 import Environment
from jinja2 import FileSystemLoader
from pkg_resources import resource_filename

class DummyTranslator(object):
    @staticmethod
    def gettext(message):
        return message

    @staticmethod
    def ngettext(singular, plural, n):
        if n > 1:
            return plural

        return singular

class jinja2_renderer_factory(object):
    def __init__(self, search_paths=(), default_templates='deform_jinja2:templates',
            translator=None, extensions=[]):

        if 'jinja2.ext.i18n' not in extensions:
           extensions.append('jinja2.ext.i18n')

        self.env = Environment(extensions=extensions)
        self.env.loader = FileSystemLoader(())

        for path in search_paths:
            self.add_search_path(path)

        if translator == None:
            translator = DummyTranslator

        self.env.install_gettext_callables(translator.gettext, translator.ngettext)

        self.add_search_path(default_templates)

    def add_search_path(self, path):
        self.env.loader.searchpath.append(resource_filename(*(path.split(':'))))

    def __call__(self, tname, **kw):
        if not '.jinja2' in tname:
            tname += '.jinja2'

        template = self.env.get_template(tname)
        return template.render(**kw)



import os

from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

try:
    README = open(os.path.join(here, 'README.rst')).read()
except:
    README = ''

requires = ['deform', 'Jinja2']

setupkw = dict(
    name='deform_jinja2',
    version='0.4',
    description='Jinja2 templates for Deform widgets',
    long_description=README,
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        ],
    keywords='web forms form generation schema validation',
    author="John Anderson",
    author_email="sontek@gmail.com",
    url="https://github.com/sontek/deform_jinja2",
    license="",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=requires,
    entry_points = """\
    [paste.app_factory]
    demo = deformdemo.app:run
    """,
    )

setup(**setupkw)



from deform_jinja2.translator import PyramidTranslator
from deform_jinja2 import jinja2_renderer_factory

jinja2_renderer = jinja2_renderer_factory(search_paths=('deformdemo:templates/',), translator=PyramidTranslator())
